import type { Context, HBox, VBox, Kern, Dist, Glyph, Node, HRule } from './types';
export declare const rebox: (box: HBox, before: Kern, after: Kern) => HBox;
export declare const makeKern: (size: Dist, flag?: "start" | "end") => Kern;
export declare const makeHRule: (thickness: number, width: number) => HRule;
export declare const makeGlyph: (char: string, glyphID: number, context: Context, isDelimiter?: boolean) => Glyph;
export declare const getCharAdvance: (glyph: Glyph) => number;
export declare const getCharBearingX: (glyph: Glyph) => number;
export declare const getCharWidth: (glyph: Glyph) => number;
export declare const getCharHeight: (glyph: Glyph) => number;
export declare const getCharDepth: (glyph: Glyph) => number;
export declare const getWidth: (node: Node) => number;
export declare const getHeight: (node: Node) => number;
export declare const getDepth: (node: Node) => number;
export declare const vsize: (node: Node) => number;
export declare const hlistWidth: (nodes: readonly Node[]) => number;
export declare const makeStaticHBox: (nodes: readonly Node[], context: Context) => HBox;
export declare const makeCursorHBox: (left: readonly Node[], right: readonly Node[], context: Context) => HBox;
export declare const makeSelectionHBox: (left: readonly Node[], selection: readonly Node[], right: readonly Node[], context: Context) => HBox;
export declare const makeVBox: (width: Dist, node: Node, upList: readonly Node[], dnList: readonly Node[], context: Context) => VBox;
export declare const getConstantValue: (constant: number, context: Context) => number;
export declare const multiplierForContext: (context: Context) => number;
export declare const fontSizeForContext: (context: Context) => number;
type ThresholdOptions = {
    readonly value: 'both' | 'sum';
    readonly strict: boolean;
};
/**
 * Returns the smallest delimiter whose depth and height exceed the that of the
 * box passed in.  `thresholdOptions` controls how this comparison is made.
 *
 * @param {string} char
 * @param {Box} box layout encompassed by the delimiter
 * @param {ThresholdOptions} options
 * @param {Context} context
 * @returns {Glyph}
 */
export declare const makeDelimiter: (char: string, box: HBox | VBox, thresholdOptions: ThresholdOptions, context: Context) => Glyph;
export {};
