import * as types from './types';
import type { FontData } from '@math-blocks/opentype';
type Style = {
    readonly fill?: string;
    readonly stroke?: string;
};
type Common = {
    readonly id?: number;
    readonly style: Style;
    readonly key?: string;
    readonly className?: string;
};
export type Group = {
    readonly type: 'group';
    readonly x: number;
    readonly y: number;
    readonly bounds: types.Dim;
    readonly children: readonly Node[];
} & Common;
export type Glyph = {
    readonly type: 'char';
    readonly x: number;
    readonly y: number;
    readonly width: number;
    readonly glyph: types.Glyph;
} & Common;
export type Line = {
    readonly type: 'line';
    readonly x1: number;
    readonly y1: number;
    readonly x2: number;
    readonly y2: number;
    readonly thickness: number;
} & Common;
export type Rect = {
    readonly type: 'rect';
    readonly x: number;
    readonly y: number;
    readonly width: number;
    readonly height: number;
    readonly fill?: string;
    readonly stroke?: string;
    readonly flag?: 'start' | 'end';
} & Common;
export type Node = Group | Glyph | Line | Rect;
export type Point = {
    readonly x: number;
    readonly y: number;
};
export type LayoutCursor = {
    readonly parent: number;
    readonly prev: number;
    readonly next: number;
    readonly selection: boolean;
};
type Options = {
    readonly showCursor?: boolean;
    readonly debug?: boolean;
};
export type Scene = {
    readonly width: number;
    readonly height: number;
    readonly content: Group;
    readonly selection: Group;
    readonly hitboxes: Group;
    readonly debug: Group;
};
export declare const processBox: (box: types.HBox, fontData: FontData, options?: Options) => Scene;
export declare const findIntersections: (point: Point, node: Group, translation?: Point) => types.Intersection[];
export {};
